@@ -20,7 +20,6 @@ public:
     virtual ~AbstractDrKonqiBackend();
     virtual bool init();
     virtual void prepareForDebugger();
-    void cleanup(); // cleanup on-disk caches
 
     inline CrashedApplication *crashedApplication() const
     {
@@ -36,6 +35,7 @@ public:
 
 Q_SIGNALS:
     void preparedForDebugger();
+    void failedToPrepare();
 
 protected:
     virtual CrashedApplication *constructCrashedApplication() = 0;
